@@ -498,7 +498,7 @@ class ResourceSet(object):
 
     def any(self):
         objs = list(self._store.objects(self._subject._id, self._predicate))
-        if len(list) > 0:
+        if len(objs) > 0:
             return objs[0]
         else:
             return None
